package models

import "time"

type Time time.Time

const (
	timeFormart = "2006-01-02 15:04:05"
)

func (t *Time) UnmarshalJSON(data []byte) (err error) {
	now, err := time.ParseInLocation(`"`+timeFormart+`"`, string(data), time.Local)
	*t = Time(now)
	return
}

func (t *Time) Parse(date string) (now time.Time, err error) {
	now, err = time.ParseInLocation(timeFormart, date, time.Local)
	*t = Time(now)
	return
}

func (t Time) MarshalJSON() ([]byte, error) {
	b := make([]byte, 0, len(timeFormart)+2)
	b = append(b, '"')
	b = time.Time(t).AppendFormat(b, timeFormart)
	b = append(b, '"')
	return b, nil
}
func (t Time) String() string {
	return time.Time(t).Format(timeFormart)
}

type WxXcxLoginReq struct {
	Code string `json:"code"`
}

type WxXcxLoginResp struct {
	Token     string `json:"token"`
	OpenId    string `json:"openid"`
	PatientId int64  ` json:"patient_id"`
	UserOrgId int64  ` json:"user_org_id"`
}

type SaveUserInfoReq struct {
	Phone string `json:"phone" description:"手机号码"`
	Email string `json:"email" description:"邮件"`
	//UnionId                 string `json:"union_id" description:"unionid"`
	NickName string `json:"nick_name" description:"昵称"`
	Avatar   string `json:"avatar" description:"头像"`
	//PrivacyProtocolVersions int    `json:"privacy_protocol_versions" description:"隐私政策版本"`

	RealName          string `json:"real_name" description:"真实姓名"`
	IdCard            string `json:"id_card" description:"身份证号"`
	InpatientRegPhone string `json:"inpatient_reg_phone" description:"住院登记手机号"`
}

type UserInfoResp struct {
	Id                      uint64 `json:"id" description:"Primary Key ID"`
	Phone                   string `json:"phone" description:"手机号码"`
	Email                   string `json:"email" description:"邮件"`
	OpenId                  string `json:"open_id" description:"OpenID"`
	UnionId                 string `json:"union_id" description:"unionid"`
	NickName                string `json:"nick_name" description:"昵称"`
	Avatar                  string `json:"avatar" description:"头像"`
	Status                  int    `json:"status" description:"状态(1:有效0:无效)"`
	Source                  string `json:"source" description:"用户来源"`
	PrivacyProtocolVersions int    `json:"privacy_protocol_versions" description:"隐私政策版本"`

	RealName          string `json:"real_name" description:"真实姓名"`
	IdCard            string `json:"id_card" description:"身份证号"`
	InpatientRegPhone string `json:"inpatient_reg_phone" description:"住院登记手机号"`

	Ctime Time `json:"ctime" description:"创建时间"`
	Mtime Time `json:"mtime" description:"更新时间 "`
}

type SaveHealthProfileReq struct {
	Gender              int    `json:"gender" description:"性别(0:未知 1:男 2:女)"`
	Height              int    `json:"height" description:"身高"`
	Weight              int    `json:"weight" description:"体重"`
	BloodType           string `json:"blood_type" description:"血型"`
	Birthday            string `json:"birthday" description:"生日 yyyy-MM-dd HH:mm:ss"`
	IllnessState        string `json:"illness_state" description:"病情"`
	RenalFunctionStatus int    `json:"renal_function_status" description:"肾功能情况(0:未透析,1: 血液透析,2:腹膜透析,3:肾脏移植)"`
	Creatinine          int    `json:"creatinine" description:"血肌酐"`
	CreatinineUnit      string `json:"creatinine_unit" description:"肌酐单位(umol/L,mg/dl)"`
	CreatineTime        string `json:"creatine_time" description:"肌酐检测时间 yyyy-MM-dd HH:mm:ss"`
	UrineProtein24hUnit string `json:"urine_protein_24h_unit" description:"24小时尿蛋白单位(g/24h,mg/24h)"`
	UrineProtein24h     int    `json:"urine_protein_24h" description:"24小时尿蛋白"`
	UrineProtein24hTime string `json:"urine_protein_24h_time" description:"24小时尿蛋白检测时间 yyyy-MM-dd HH:mm:ss"`
	UrineProtein        int    `json:"urine_protein" description:"尿蛋白"`
	UrineProteinUnit    string `json:"urine_protein_unit" description:"尿蛋白单位(g,mg)"`
	UrineProteinTime    string `json:"urine_protein_time" description:"尿蛋白检测时间 yyyy-MM-dd HH:mm:ss"`
}

type HealthProfileResp struct {
	Id uint64 `json:"id" description:"Primary Key ID"`
	//UserId              int64     `json:"user_id" description:"用户ID"`
	//RealName            string    `json:"real_name" description:"真实姓名"`
	//IdCard              string    `json:"id_card" description:"身份证号"`
	//InpatientRegPhone   string    `json:"inpatient_reg_phone" description:"住院登记手机号"`
	Gender              int    `json:"gender" description:"性别(0:未知 1:男 2:女)"`
	Height              int    `json:"height" description:"身高"`
	Weight              int    `json:"weight" description:"体重"`
	BloodType           string `json:"blood_type" description:"血型"`
	Birthday            Time   `json:"birthday" description:"生日"`
	IllnessState        string `json:"illness_state" description:"病情"`
	RenalFunctionStatus int    `json:"renal_function_status" description:"肾功能情况(0:未透析,1: 血液透析,2:腹膜透析,3:肾脏移植)"`
	Creatinine          int    `json:"creatinine" description:"血肌酐"`
	CreatinineUnit      string `json:"creatinine_unit" description:"肌酐单位(umol/L,mg/dl)"`
	CreatineTime        Time   `json:"creatine_time" description:"肌酐检测时间"`
	UrineProtein24hUnit string `json:"urine_protein_24h_unit" description:"24小时尿蛋白单位(g/24h,mg/24h)"`
	UrineProtein24h     int    `json:"urine_protein_24h" description:"24小时尿蛋白"`
	UrineProtein24hTime Time   `json:"urine_protein_24h_time" description:"24小时尿蛋白检测时间"`
	UrineProtein        int    `json:"urine_protein" description:"尿蛋白"`
	UrineProteinUnit    string `json:"urine_protein_unit" description:"尿蛋白单位(g,mg)"`
	UrineProteinTime    Time   `json:"urine_protein_time" description:"尿蛋白检测时间"`
	Status              int    `json:"status" description:"状态(1:有效 0:无效 )"`
	Ctime               Time   `json:"ctime" description:"创建时间"`
	Mtime               Time   `json:"mtime" description:"更新时间 "`
}

type DicResp struct {
	Type  string `json:"type"`
	Name  string `json:"name" description:"字典名称"`
	Value int    `json:"value" description:"字典值"`
}

type OpenEmqMsgReqV0 struct {
	UserName   string `json:"username" description:"用户名"`
	Topic      string `json:"topic" description:"主题"`
	PeerHost   string `json:"peerhost" description:"主机"`
	Payload    string `json:"payload" description:"负载"`
	Id         string `json:"id"`
	ProductKey string `json:"productKey" description:"产品key"`
	DeviceName string `json:"deviceName" description:"设备名称"`
	Acc        int    `json:"acc"`
	Type       int    `json:"type"`
	Count      int    `json:"count"`
	DataType   int    `json:"datatype"`
	VerifyCode string `json:"verifycode"`
	Data       string `json:"data"`
	Origin     string `json:"origin"`
	Len        int    `json:"len"`
}

type OpenEmqPayloadReqVO struct {
	ProductKey string `json:"productKey"` // 产品密钥
	DeviceName string `json:"deviceName"` // 设备名称
	Acc        int    `json:"acc"`        // 准确度
	Type       int    `json:"type"`       // 类型
	Count      int    `json:"count"`      // 计数
	Datatype   int    `json:"datatype"`   // 数据类型
	Verifycode int    `json:"verifycode"` // 验证码
	Data       string `json:"data"`       // 数据
	Origin     string `json:"origin"`     // 来源
	Len        int    `json:"len"`        // 长度
}
type CheckItemScopeVO struct {
	Index int     `json:"index"`
	Type  int     `json:"type"`
	Value string  `json:"value"`
	Num   float64 `json:"num"`
}
